# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    Authdata,
    DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem,
    McpServerGetToolsResponse,
    Servers,
)

__all__ = [
    "Authdata",
    "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem",
    "McpServerGetToolsResponse",
    "Servers",
]



# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.list_tools_response import ListToolsResponse
from ...types.multi_server_tools_response import MultiServerToolsResponse

McpServerGetToolsResponse = typing.Union[ListToolsResponse, MultiServerToolsResponse]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .types import (
    ApiKeyAuth,
    CallToolResponse,
    CallToolResult,
    ConnectionType,
    CreateSelfHostedServerResponse,
    CreateServerResponse,
    DeleteUserResponse,
    ExtendedMcpServer,
    ExternalServerInfo,
    ExternalServerRequest,
    GeneralAuth,
    GetAuthDataResponse,
    GetInstanceResponse,
    GetMcpServersResponse,
    GetServerInstancesResponse,
    HttpValidationError,
    ListToolsResponse,
    McpServer,
    McpServerName,
    MultiServerToolsResponse,
    OAuthServerName,
    ServerTool,
    ServerToolsResult,
    StatusResponse,
    StrataAddServersResponse,
    StrataCreateResponse,
    StrataDeleteServersResponse,
    StrataGetResponse,
    ToolFormat,
    ValidationError,
    ValidationErrorLocItem,
    WhiteLabelingResponse,
)
from .errors import UnprocessableEntityError
from . import mcp_server, oauth, user, white_labeling
from .client import AsyncKlavis, Klavis
from .environment import KlavisEnvironment
from .mcp_server import (
    Authdata,
    DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem,
    McpServerGetToolsResponse,
    Servers,
)
from .oauth import Environment
from .version import __version__

__all__ = [
    "ApiKeyAuth",
    "AsyncKlavis",
    "Authdata",
    "CallToolResponse",
    "CallToolResult",
    "ConnectionType",
    "CreateSelfHostedServerResponse",
    "CreateServerResponse",
    "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem",
    "DeleteUserResponse",
    "Environment",
    "ExtendedMcpServer",
    "ExternalServerInfo",
    "ExternalServerRequest",
    "GeneralAuth",
    "GetAuthDataResponse",
    "GetInstanceResponse",
    "GetMcpServersResponse",
    "GetServerInstancesResponse",
    "HttpValidationError",
    "Klavis",
    "KlavisEnvironment",
    "ListToolsResponse",
    "McpServer",
    "McpServerGetToolsResponse",
    "McpServerName",
    "MultiServerToolsResponse",
    "OAuthServerName",
    "ServerTool",
    "ServerToolsResult",
    "Servers",
    "StatusResponse",
    "StrataAddServersResponse",
    "StrataCreateResponse",
    "StrataDeleteServersResponse",
    "StrataGetResponse",
    "ToolFormat",
    "UnprocessableEntityError",
    "ValidationError",
    "ValidationErrorLocItem",
    "WhiteLabelingResponse",
    "__version__",
    "mcp_server",
    "oauth",
    "user",
    "white_labeling",
]



# This file was auto-generated by Fern from our API Definition.

# isort: skip_file

from .authdata import Authdata
from .delete_servers_from_strata_mcp_server_strata_strata_id_servers_delete_request_servers_item import (
    DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem,
)
from .mcp_server_get_tools_response import McpServerGetToolsResponse
from .servers import Servers

__all__ = [
    "Authdata",
    "DeleteServersFromStrataMcpServerStrataStrataIdServersDeleteRequestServersItem",
    "McpServerGetToolsResponse",
    "Servers",
]



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from .server_tools_result import ServerToolsResult
from .tool_format import ToolFormat


class MultiServerToolsResponse(UniversalBaseModel):
    success: bool = pydantic.Field()
    """
    Whether tools were retrieved successfully for all requested servers.
    """

    format: ToolFormat = pydantic.Field()
    """
    The format of the returned tools for all servers.
    """

    results: typing.Optional[typing.List[ServerToolsResult]] = pydantic.Field(default=None)
    """
    Per-server results including any partial failures.
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    Aggregated error message when one or more servers fail.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow



# This file was auto-generated by Fern from our API Definition.

import typing

import pydantic
import typing_extensions
from ..core.pydantic_utilities import IS_PYDANTIC_V2, UniversalBaseModel
from ..core.serialization import FieldMetadata


class ServerToolsResult(UniversalBaseModel):
    server_name: typing_extensions.Annotated[str, FieldMetadata(alias="serverName")] = pydantic.Field()
    """
    The name of the MCP server.
    """

    success: bool = pydantic.Field()
    """
    Whether the tools were retrieved successfully for this server.
    """

    tools: typing.Optional[typing.List[typing.Optional[typing.Any]]] = pydantic.Field(default=None)
    """
    Tools available for the server when the request succeeds.
    """

    error: typing.Optional[str] = pydantic.Field(default=None)
    """
    The error message if the request failed for this server.
    """

    if IS_PYDANTIC_V2:
        model_config: typing.ClassVar[pydantic.ConfigDict] = pydantic.ConfigDict(extra="allow", frozen=True)  # type: ignore # Pydantic v2
    else:

        class Config:
            frozen = True
            smart_union = True
            extra = pydantic.Extra.allow
